models

package
v0.0.0-...-db05ea5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AccountReturnModel

type AccountReturnModel struct {

	// 24hnumreward
	Nr24hnumreward int64 `json:"24hnumreward,omitempty"`

	// 24hreward
	Nr24hreward int64 `json:"24hreward,omitempty"`

	// current hashrate
	CurrentHashrate float32 `json:"currentHashrate,omitempty"`

	// current luck
	CurrentLuck string `json:"currentLuck,omitempty"`

	// hashrate
	Hashrate float32 `json:"hashrate,omitempty"`

	// page size
	PageSize int64 `json:"pageSize,omitempty"`

	// payments
	Payments []*PaymentModel `json:"payments"`

	// payments total
	PaymentsTotal int64 `json:"paymentsTotal,omitempty"`

	// rewards
	Rewards []*RewardsModel `json:"rewards"`

	// round shares
	RoundShares int64 `json:"roundShares,omitempty"`

	// shares
	Shares []string `json:"shares"`

	// stats
	Stats *StatsModel `json:"stats,omitempty"`

	// sumrewards
	Sumrewards []*SumrewardsModel `json:"sumrewards"`

	// workers
	Workers map[string]WorkerGroupModel `json:"workers,omitempty"`

	// workers offline
	WorkersOffline int64 `json:"workersOffline,omitempty"`

	// workers online
	WorkersOnline int64 `json:"workersOnline,omitempty"`

	// workers total
	WorkersTotal int64 `json:"workersTotal,omitempty"`
}

AccountReturnModel account return model

swagger:model AccountReturnModel

func (*AccountReturnModel) ContextValidate

func (m *AccountReturnModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this account return model based on the context it is used

func (*AccountReturnModel) MarshalBinary

func (m *AccountReturnModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*AccountReturnModel) UnmarshalBinary

func (m *AccountReturnModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*AccountReturnModel) Validate

func (m *AccountReturnModel) Validate(formats strfmt.Registry) error

Validate validates this account return model

type Addr

type Addr struct {

	// addr
	// Min Length: 1
	Addr string `json:"Addr,omitempty"`

	// block
	Block int64 `json:"Block,omitempty"`

	// Id
	ID int64 `json:"Id,omitempty"`

	// monitor addr
	MonitorAddr bool `json:"MonitorAddr,omitempty"`

	// monitor block
	MonitorBlock bool `json:"MonitorBlock,omitempty"`

	// notify
	Notify int64 `json:"Notify,omitempty"`

	// pool
	// Min Length: 1
	Pool string `json:"Pool,omitempty"`
}

Addr addr

swagger:model Addr

func (*Addr) ContextValidate

func (m *Addr) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this addr based on context it is used

func (*Addr) MarshalBinary

func (m *Addr) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Addr) UnmarshalBinary

func (m *Addr) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Addr) Validate

func (m *Addr) Validate(formats strfmt.Registry) error

Validate validates this addr

type Address

type Address []*Addr

Address address

swagger:model Address

func (Address) ContextValidate

func (m Address) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this address based on the context it is used

func (Address) Validate

func (m Address) Validate(formats strfmt.Registry) error

Validate validates this address

type BlockReturnModel

type BlockReturnModel struct {

	// candidates
	Candidates []*CandidatesModel `json:"candidates"`

	// candidates total
	CandidatesTotal int64 `json:"candidatesTotal,omitempty"`

	// immature
	Immature []*ImMaturedModel `json:"immature"`

	// immature total
	ImmatureTotal int64 `json:"immatureTotal,omitempty"`

	// luck
	Luck *LuckModel `json:"luck,omitempty"`

	// matured
	Matured []*MaturedModel `json:"matured"`

	// matured total
	MaturedTotal int64 `json:"maturedTotal,omitempty"`
}

BlockReturnModel block return model

swagger:model BlockReturnModel

func (*BlockReturnModel) ContextValidate

func (m *BlockReturnModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this block return model based on the context it is used

func (*BlockReturnModel) MarshalBinary

func (m *BlockReturnModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*BlockReturnModel) UnmarshalBinary

func (m *BlockReturnModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*BlockReturnModel) Validate

func (m *BlockReturnModel) Validate(formats strfmt.Registry) error

Validate validates this block return model

type CandidatesModel

type CandidatesModel struct {

	// difficulty
	Difficulty float32 `json:"difficulty,omitempty"`

	// finder
	Finder string `json:"finder,omitempty"`

	// hash
	Hash string `json:"hash,omitempty"`

	// height
	Height int64 `json:"height,omitempty"`

	// orphan
	Orphan *bool `json:"orphan,omitempty"`

	// reward
	Reward int64 `json:"reward,omitempty"`

	// shares
	Shares float32 `json:"shares,omitempty"`

	// timestamp
	Timestamp int64 `json:"timestamp,omitempty"`

	// uncle
	Uncle *bool `json:"uncle,omitempty"`

	// uncle height
	UncleHeight int64 `json:"uncleHeight,omitempty"`
}

CandidatesModel candidates model

swagger:model CandidatesModel

func (*CandidatesModel) ContextValidate

func (m *CandidatesModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this candidates model based on context it is used

func (*CandidatesModel) MarshalBinary

func (m *CandidatesModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*CandidatesModel) UnmarshalBinary

func (m *CandidatesModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*CandidatesModel) Validate

func (m *CandidatesModel) Validate(formats strfmt.Registry) error

Validate validates this candidates model

type ExceptionModel

type ExceptionModel struct {

	// code
	Code int64 `json:"code,omitempty"`

	// description
	Description string `json:"description,omitempty"`

	// message
	Message string `json:"message,omitempty"`
}

ExceptionModel exception model

swagger:model ExceptionModel

func (*ExceptionModel) ContextValidate

func (m *ExceptionModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this exception model based on context it is used

func (*ExceptionModel) MarshalBinary

func (m *ExceptionModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*ExceptionModel) UnmarshalBinary

func (m *ExceptionModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*ExceptionModel) Validate

func (m *ExceptionModel) Validate(formats strfmt.Registry) error

Validate validates this exception model

type FormLoginPassword

type FormLoginPassword struct {

	// login
	Login string `json:"Login,omitempty"`

	// password
	Password string `json:"Password,omitempty"`
}

FormLoginPassword form login password

swagger:model FormLoginPassword

func (*FormLoginPassword) ContextValidate

func (m *FormLoginPassword) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this form login password based on context it is used

func (*FormLoginPassword) MarshalBinary

func (m *FormLoginPassword) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*FormLoginPassword) UnmarshalBinary

func (m *FormLoginPassword) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*FormLoginPassword) Validate

func (m *FormLoginPassword) Validate(formats strfmt.Registry) error

Validate validates this form login password

type ImMaturedModel

type ImMaturedModel struct {

	// difficulty
	Difficulty float32 `json:"difficulty,omitempty"`

	// finder
	Finder string `json:"finder,omitempty"`

	// hash
	Hash string `json:"hash,omitempty"`

	// height
	Height int64 `json:"height,omitempty"`

	// orphan
	Orphan *bool `json:"orphan,omitempty"`

	// reward
	Reward int64 `json:"reward,omitempty"`

	// shares
	Shares float32 `json:"shares,omitempty"`

	// timestamp
	Timestamp int64 `json:"timestamp,omitempty"`

	// uncle
	Uncle *bool `json:"uncle,omitempty"`

	// uncle height
	UncleHeight int64 `json:"uncleHeight,omitempty"`
}

ImMaturedModel im matured model

swagger:model ImMaturedModel

func (*ImMaturedModel) ContextValidate

func (m *ImMaturedModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this im matured model based on context it is used

func (*ImMaturedModel) MarshalBinary

func (m *ImMaturedModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*ImMaturedModel) UnmarshalBinary

func (m *ImMaturedModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*ImMaturedModel) Validate

func (m *ImMaturedModel) Validate(formats strfmt.Registry) error

Validate validates this im matured model

type LuckModel

type LuckModel struct {

	// luck number
	LuckNumber *LuckNumberModel `json:"luckNumber,omitempty"`
}

LuckModel luck model

swagger:model LuckModel

func (*LuckModel) ContextValidate

func (m *LuckModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this luck model based on the context it is used

func (*LuckModel) MarshalBinary

func (m *LuckModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*LuckModel) UnmarshalBinary

func (m *LuckModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*LuckModel) Validate

func (m *LuckModel) Validate(formats strfmt.Registry) error

Validate validates this luck model

type LuckNumberModel

type LuckNumberModel struct {

	// luck
	Luck float32 `json:"luck,omitempty"`

	// orphan rate
	OrphanRate float64 `json:"orphanRate,omitempty"`
}

LuckNumberModel luck number model

swagger:model LuckNumberModel

func (*LuckNumberModel) ContextValidate

func (m *LuckNumberModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this luck number model based on context it is used

func (*LuckNumberModel) MarshalBinary

func (m *LuckNumberModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*LuckNumberModel) UnmarshalBinary

func (m *LuckNumberModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*LuckNumberModel) Validate

func (m *LuckNumberModel) Validate(formats strfmt.Registry) error

Validate validates this luck number model

type MaturedModel

type MaturedModel struct {

	// difficulty
	Difficulty float32 `json:"difficulty,omitempty"`

	// finder
	Finder string `json:"finder,omitempty"`

	// hash
	Hash string `json:"hash,omitempty"`

	// height
	Height int64 `json:"height,omitempty"`

	// orphan
	Orphan *bool `json:"orphan,omitempty"`

	// reward
	Reward int64 `json:"reward,omitempty"`

	// shares
	Shares float32 `json:"shares,omitempty"`

	// timestamp
	Timestamp int64 `json:"timestamp,omitempty"`

	// uncle
	Uncle *bool `json:"uncle,omitempty"`

	// uncle height
	UncleHeight int64 `json:"uncleHeight,omitempty"`
}

MaturedModel matured model

swagger:model MaturedModel

func (*MaturedModel) ContextValidate

func (m *MaturedModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this matured model based on context it is used

func (*MaturedModel) MarshalBinary

func (m *MaturedModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*MaturedModel) UnmarshalBinary

func (m *MaturedModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*MaturedModel) Validate

func (m *MaturedModel) Validate(formats strfmt.Registry) error

Validate validates this matured model

type MinerModel

type MinerModel struct {

	// miner Uid
	MinerUID *MinerUIDModel `json:"minerUid,omitempty"`
}

MinerModel miner model

swagger:model MinerModel

func (*MinerModel) ContextValidate

func (m *MinerModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this miner model based on the context it is used

func (*MinerModel) MarshalBinary

func (m *MinerModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*MinerModel) UnmarshalBinary

func (m *MinerModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*MinerModel) Validate

func (m *MinerModel) Validate(formats strfmt.Registry) error

Validate validates this miner model

type MinerReturnModel

type MinerReturnModel struct {

	// hashrate
	Hashrate float32 `json:"hashrate,omitempty"`

	// miners
	Miners *MinerModel `json:"miners,omitempty"`

	// miners total
	MinersTotal int64 `json:"minersTotal,omitempty"`

	// now
	Now int64 `json:"now,omitempty"`
}

MinerReturnModel miner return model

swagger:model MinerReturnModel

func (*MinerReturnModel) ContextValidate

func (m *MinerReturnModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this miner return model based on the context it is used

func (*MinerReturnModel) MarshalBinary

func (m *MinerReturnModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*MinerReturnModel) UnmarshalBinary

func (m *MinerReturnModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*MinerReturnModel) Validate

func (m *MinerReturnModel) Validate(formats strfmt.Registry) error

Validate validates this miner return model

type MinerUIDModel

type MinerUIDModel struct {

	// height
	Height int64 `json:"height,omitempty"`

	// last beat
	LastBeat int64 `json:"lastBeat,omitempty"`

	// offline
	Offline *bool `json:"offline,omitempty"`
}

MinerUIDModel miner Uid model

swagger:model MinerUidModel

func (*MinerUIDModel) ContextValidate

func (m *MinerUIDModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this miner Uid model based on context it is used

func (*MinerUIDModel) MarshalBinary

func (m *MinerUIDModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*MinerUIDModel) UnmarshalBinary

func (m *MinerUIDModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*MinerUIDModel) Validate

func (m *MinerUIDModel) Validate(formats strfmt.Registry) error

Validate validates this miner Uid model

type NodeModel

type NodeModel struct {

	// avg block time
	AvgBlockTime string `json:"avgBlockTime,omitempty"`

	// difficulty
	Difficulty string `json:"difficulty,omitempty"`

	// height
	Height string `json:"height,omitempty"`

	// last beat
	LastBeat string `json:"lastBeat,omitempty"`

	// name
	Name string `json:"name,omitempty"`

	// networkhashps
	Networkhashps string `json:"networkhashps,omitempty"`
}

NodeModel node model

swagger:model NodeModel

func (*NodeModel) ContextValidate

func (m *NodeModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this node model based on context it is used

func (*NodeModel) MarshalBinary

func (m *NodeModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*NodeModel) UnmarshalBinary

func (m *NodeModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*NodeModel) Validate

func (m *NodeModel) Validate(formats strfmt.Registry) error

Validate validates this node model

type PaymentModel

type PaymentModel struct {

	// amount
	Amount int64 `json:"amount,omitempty"`

	// timestamp
	Timestamp int64 `json:"timestamp,omitempty"`

	// tx
	Tx string `json:"tx,omitempty"`
}

PaymentModel payment model

swagger:model PaymentModel

func (*PaymentModel) ContextValidate

func (m *PaymentModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this payment model based on context it is used

func (*PaymentModel) MarshalBinary

func (m *PaymentModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*PaymentModel) UnmarshalBinary

func (m *PaymentModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*PaymentModel) Validate

func (m *PaymentModel) Validate(formats strfmt.Registry) error

Validate validates this payment model

type PaymentReturnModel

type PaymentReturnModel struct {

	// payments
	Payments []*PaymentsModel `json:"payments"`

	// payments total
	PaymentsTotal int64 `json:"paymentsTotal,omitempty"`
}

PaymentReturnModel payment return model

swagger:model PaymentReturnModel

func (*PaymentReturnModel) ContextValidate

func (m *PaymentReturnModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this payment return model based on the context it is used

func (*PaymentReturnModel) MarshalBinary

func (m *PaymentReturnModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*PaymentReturnModel) UnmarshalBinary

func (m *PaymentReturnModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*PaymentReturnModel) Validate

func (m *PaymentReturnModel) Validate(formats strfmt.Registry) error

Validate validates this payment return model

type PaymentsModel

type PaymentsModel struct {

	// amount
	Amount int64 `json:"amount,omitempty"`

	// timestamp
	Timestamp int64 `json:"timestamp,omitempty"`

	// total payees
	TotalPayees int64 `json:"totalPayees,omitempty"`

	// tx
	Tx string `json:"tx,omitempty"`
}

PaymentsModel payments model

swagger:model PaymentsModel

func (*PaymentsModel) ContextValidate

func (m *PaymentsModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this payments model based on context it is used

func (*PaymentsModel) MarshalBinary

func (m *PaymentsModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*PaymentsModel) UnmarshalBinary

func (m *PaymentsModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*PaymentsModel) Validate

func (m *PaymentsModel) Validate(formats strfmt.Registry) error

Validate validates this payments model

type PoolChartsModel

type PoolChartsModel struct {

	// netdiff
	Netdiff float32 `json:"netdiff,omitempty"`

	// nethr
	Nethr float32 `json:"nethr,omitempty"`

	// time format
	TimeFormat string `json:"timeFormat,omitempty"`

	// x
	X int64 `json:"x,omitempty"`

	// y
	Y float32 `json:"y,omitempty"`
}

PoolChartsModel pool charts model

swagger:model PoolChartsModel

func (*PoolChartsModel) ContextValidate

func (m *PoolChartsModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this pool charts model based on context it is used

func (*PoolChartsModel) MarshalBinary

func (m *PoolChartsModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*PoolChartsModel) UnmarshalBinary

func (m *PoolChartsModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*PoolChartsModel) Validate

func (m *PoolChartsModel) Validate(formats strfmt.Registry) error

Validate validates this pool charts model

type RewardsModel

type RewardsModel struct {

	// blockhash
	Blockhash string `json:"blockhash,omitempty"`

	// blockheight
	Blockheight int64 `json:"blockheight,omitempty"`

	// current luck
	CurrentLuck float32 `json:"currentLuck,omitempty"`

	// immature
	Immature *bool `json:"immature,omitempty"`

	// percent
	Percent float32 `json:"percent,omitempty"`

	// reward
	Reward int64 `json:"reward,omitempty"`

	// timestamp
	Timestamp int64 `json:"timestamp,omitempty"`

	// uncle
	Uncle *bool `json:"uncle,omitempty"`
}

RewardsModel rewards model

swagger:model RewardsModel

func (*RewardsModel) ContextValidate

func (m *RewardsModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this rewards model based on context it is used

func (*RewardsModel) MarshalBinary

func (m *RewardsModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*RewardsModel) UnmarshalBinary

func (m *RewardsModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*RewardsModel) Validate

func (m *RewardsModel) Validate(formats strfmt.Registry) error

Validate validates this rewards model

type StatsAddr

type StatsAddr struct {

	// balance
	Balance string `json:"Balance,omitempty"`

	// current hash rate
	CurrentHashRate string `json:"CurrentHashRate,omitempty"`

	// current luck
	CurrentLuck string `json:"CurrentLuck,omitempty"`

	// hash rate
	HashRate string `json:"HashRate,omitempty"`

	// immature
	Immature string `json:"Immature,omitempty"`

	// last block found
	LastBlockFound int64 `json:"LastBlockFound,omitempty"`

	// payed
	Payed string `json:"Payed,omitempty"`

	// sum rewards
	SumRewards []*SumRewards `json:"SumRewards"`

	// workers
	Workers []*Worker `json:"Workers"`
}

StatsAddr stats addr

swagger:model StatsAddr

func (*StatsAddr) ContextValidate

func (m *StatsAddr) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this stats addr based on the context it is used

func (*StatsAddr) MarshalBinary

func (m *StatsAddr) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*StatsAddr) UnmarshalBinary

func (m *StatsAddr) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*StatsAddr) Validate

func (m *StatsAddr) Validate(formats strfmt.Registry) error

Validate validates this stats addr

type StatsModel

type StatsModel struct {

	// balance
	Balance int64 `json:"balance,omitempty"`

	// blocks found
	BlocksFound int64 `json:"blocksFound,omitempty"`

	// immature
	Immature int64 `json:"immature,omitempty"`

	// last share
	LastShare int64 `json:"lastShare,omitempty"`

	// paid
	Paid int64 `json:"paid,omitempty"`

	// pending
	Pending int64 `json:"pending,omitempty"`
}

StatsModel stats model

swagger:model StatsModel

func (*StatsModel) ContextValidate

func (m *StatsModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this stats model based on context it is used

func (*StatsModel) MarshalBinary

func (m *StatsModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*StatsModel) UnmarshalBinary

func (m *StatsModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*StatsModel) Validate

func (m *StatsModel) Validate(formats strfmt.Registry) error

Validate validates this stats model

type StatsReturnModel

type StatsReturnModel struct {

	// candidates total
	CandidatesTotal int64 `json:"candidatesTotal,omitempty"`

	// hashrate
	Hashrate float32 `json:"hashrate,omitempty"`

	// immature total
	ImmatureTotal int64 `json:"immatureTotal,omitempty"`

	// luck
	Luck float32 `json:"luck,omitempty"`

	// matured total
	MaturedTotal int64 `json:"maturedTotal,omitempty"`

	// miners total
	MinersTotal int64 `json:"minersTotal,omitempty"`

	// nodes
	Nodes []*NodeModel `json:"nodes"`

	// now
	Now int64 `json:"now,omitempty"`

	// payments total
	PaymentsTotal int64 `json:"paymentsTotal,omitempty"`

	// pool charts
	PoolCharts []*PoolChartsModel `json:"poolCharts"`

	// stats
	Stats *StatsReturnModelStats `json:"stats,omitempty"`
}

StatsReturnModel stats return model

swagger:model StatsReturnModel

func (*StatsReturnModel) ContextValidate

func (m *StatsReturnModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this stats return model based on the context it is used

func (*StatsReturnModel) MarshalBinary

func (m *StatsReturnModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*StatsReturnModel) UnmarshalBinary

func (m *StatsReturnModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*StatsReturnModel) Validate

func (m *StatsReturnModel) Validate(formats strfmt.Registry) error

Validate validates this stats return model

type StatsReturnModelStats

type StatsReturnModelStats struct {

	// last block found
	LastBlockFound int64 `json:"lastBlockFound,omitempty"`

	// nshares
	Nshares int64 `json:"nshares,omitempty"`

	// round shares
	RoundShares float32 `json:"roundShares,omitempty"`
}

StatsReturnModelStats stats return model stats

swagger:model StatsReturnModelStats

func (*StatsReturnModelStats) ContextValidate

func (m *StatsReturnModelStats) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this stats return model stats based on context it is used

func (*StatsReturnModelStats) MarshalBinary

func (m *StatsReturnModelStats) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*StatsReturnModelStats) UnmarshalBinary

func (m *StatsReturnModelStats) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*StatsReturnModelStats) Validate

func (m *StatsReturnModelStats) Validate(formats strfmt.Registry) error

Validate validates this stats return model stats

type SumRewards

type SumRewards struct {

	// name
	Name string `json:"Name,omitempty"`

	// reward
	Reward string `json:"Reward,omitempty"`
}

SumRewards sum rewards

swagger:model SumRewards

func (*SumRewards) ContextValidate

func (m *SumRewards) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this sum rewards based on context it is used

func (*SumRewards) MarshalBinary

func (m *SumRewards) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*SumRewards) UnmarshalBinary

func (m *SumRewards) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*SumRewards) Validate

func (m *SumRewards) Validate(formats strfmt.Registry) error

Validate validates this sum rewards

type SumrewardsModel

type SumrewardsModel struct {

	// inverval
	Inverval int64 `json:"inverval,omitempty"`

	// name
	Name string `json:"name,omitempty"`

	// numreward
	Numreward int64 `json:"numreward,omitempty"`

	// offset
	Offset int64 `json:"offset,omitempty"`

	// reward
	Reward int64 `json:"reward,omitempty"`
}

SumrewardsModel sumrewards model

swagger:model SumrewardsModel

func (*SumrewardsModel) ContextValidate

func (m *SumrewardsModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this sumrewards model based on context it is used

func (*SumrewardsModel) MarshalBinary

func (m *SumrewardsModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*SumrewardsModel) UnmarshalBinary

func (m *SumrewardsModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*SumrewardsModel) Validate

func (m *SumrewardsModel) Validate(formats strfmt.Registry) error

Validate validates this sumrewards model

type User

type User struct {

	// banned
	Banned bool `json:"Banned,omitempty"`

	// data
	Data []*Addr `json:"Data"`

	// email
	Email string `json:"Email,omitempty"`

	// pass
	Pass string `json:"Pass,omitempty"`

	// root
	Root bool `json:"Root,omitempty"`

	// Uid
	UID string `json:"Uid,omitempty"`
}

User user

swagger:model User

func (*User) ContextValidate

func (m *User) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this user based on the context it is used

func (*User) MarshalBinary

func (m *User) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*User) UnmarshalBinary

func (m *User) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*User) Validate

func (m *User) Validate(formats strfmt.Registry) error

Validate validates this user

type Users

type Users []*User

Users users

swagger:model Users

func (Users) ContextValidate

func (m Users) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this users based on the context it is used

func (Users) Validate

func (m Users) Validate(formats strfmt.Registry) error

Validate validates this users

type Worker

type Worker struct {

	// h r
	HR string `json:"HR,omitempty"`

	// last beat
	LastBeat string `json:"LastBeat,omitempty"`

	// name
	Name string `json:"Name,omitempty"`
}

Worker worker

swagger:model Worker

func (*Worker) ContextValidate

func (m *Worker) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this worker based on context it is used

func (*Worker) MarshalBinary

func (m *Worker) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*Worker) UnmarshalBinary

func (m *Worker) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*Worker) Validate

func (m *Worker) Validate(formats strfmt.Registry) error

Validate validates this worker

type WorkerGroupModel

type WorkerGroupModel struct {

	// hr
	Hr float32 `json:"hr,omitempty"`

	// hr2
	Hr2 float32 `json:"hr2,omitempty"`

	// last beat
	LastBeat int64 `json:"lastBeat,omitempty"`

	// offline
	Offline *bool `json:"offline,omitempty"`
}

WorkerGroupModel worker group model

swagger:model WorkerGroupModel

func (*WorkerGroupModel) ContextValidate

func (m *WorkerGroupModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this worker group model based on context it is used

func (*WorkerGroupModel) MarshalBinary

func (m *WorkerGroupModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*WorkerGroupModel) UnmarshalBinary

func (m *WorkerGroupModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*WorkerGroupModel) Validate

func (m *WorkerGroupModel) Validate(formats strfmt.Registry) error

Validate validates this worker group model

type WorkerGroupModel2

type WorkerGroupModel2 struct {

	// bits
	Bits int64 `json:"bits,omitempty"`

	// hr
	Hr float64 `json:"hr,omitempty"`

	// hr2
	Hr2 float64 `json:"hr2,omitempty"`

	// last beat
	LastBeat int64 `json:"lastBeat,omitempty"`

	// offline
	Offline *bool `json:"offline,omitempty"`
}

WorkerGroupModel2 worker group model2

swagger:model WorkerGroupModel2

func (*WorkerGroupModel2) ContextValidate

func (m *WorkerGroupModel2) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validates this worker group model2 based on context it is used

func (*WorkerGroupModel2) MarshalBinary

func (m *WorkerGroupModel2) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*WorkerGroupModel2) UnmarshalBinary

func (m *WorkerGroupModel2) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*WorkerGroupModel2) Validate

func (m *WorkerGroupModel2) Validate(formats strfmt.Registry) error

Validate validates this worker group model2

type WorkerModel

type WorkerModel struct {

	// worker group
	WorkerGroup *WorkerGroupModel `json:"workerGroup,omitempty"`
}

WorkerModel worker model

swagger:model WorkerModel

func (*WorkerModel) ContextValidate

func (m *WorkerModel) ContextValidate(ctx context.Context, formats strfmt.Registry) error

ContextValidate validate this worker model based on the context it is used

func (*WorkerModel) MarshalBinary

func (m *WorkerModel) MarshalBinary() ([]byte, error)

MarshalBinary interface implementation

func (*WorkerModel) UnmarshalBinary

func (m *WorkerModel) UnmarshalBinary(b []byte) error

UnmarshalBinary interface implementation

func (*WorkerModel) Validate

func (m *WorkerModel) Validate(formats strfmt.Registry) error

Validate validates this worker model

Jump to